==> merchant-base-0.4.26-RELEASE-sources.jar: com/rocogz/merchant/entity/exchangeGoodsPoints/MerchantExchangeGoodsPoints.java <==
package com.rocogz.merchant.entity.exchangeGoodsPoints;

import com.baomidou.mybatisplus.annotation.TableField;
import com.rocogz.merchant.entity.goods.MerchantGoods;

import java.math.BigDecimal;

import com.rocogz.syy.common.entity.UserTimeEntity;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author yifenrui
 * @since 2021-05-21
 */
@Data
@EqualsAndHashCode(callSuper = true)
@Accessors(chain = true)
public class MerchantExchangeGoodsPoints extends UserTimeEntity {

    private static final long serialVersionUID=1L;

    /**
     * 编码
     */
    private String code;

    /**
     * 代理商产品code
     */
    private String agentGoodsCode;

    /**
     * 积分商城产品名称
     */
    private String name;

    /**
     * 兑换积分
     */
    private BigDecimal exchangePoints;

    /**
     * 位置值
     */
    private Integer sort;

    /**
     * 备注
     */
    private String remark;

    /**
     * 状态 上架：UP_LIST，下架：DOWN_LIST
     */
    private String status;

    /**
     * 平台appid
     */
    private String miniAppid;

    /**
     * 平台名称-为了排序
     */
    private String miniAppidName;

    /**
     * 代理商产品-产品类型
     */
    @TableField(exist = false)
    private String agentProductName;

    /**
     * 代理商产品-产品面额/价值
     */
    @TableField(exist = false)
    private BigDecimal marketPrice;

    /**
     * 代理商产品-建议积分兑换值
     */
    @TableField(exist = false)
    private BigDecimal suggestExchangePointValue;

    /**
     * 代理商产品-代理商产品名称
     */
    @TableField(exist = false)
    private String agentGoodsName;

    /**
     * 代理商产品-代理商采购价
     */
    @TableField(exist = false)
    private BigDecimal purchasePrice;

    /**
     * 代理商产品-代理商产品状态
     */
    @TableField(exist = false)
    private String agentGoodsStatus;

    /**
     * 代理商产品-所属代理商
     */
    @TableField(exist = false)
    private String agentName;

    /**
     * 代理商编号
     */
    @TableField(exist = false)
    private String agentCode;

    @TableField(exist = false)
    private MerchantGoods MerchantGoods;




}

==> merchant-base-0.5.8-RELEASE-sources.jar: com/rocogz/merchant/entity/exchangeGoodsPoints/MerchantExchangeGoodsPoints.java <==
package com.rocogz.merchant.entity.exchangeGoodsPoints;

import com.baomidou.mybatisplus.annotation.TableField;
import com.rocogz.merchant.entity.goods.MerchantGoods;

import java.math.BigDecimal;

import com.rocogz.syy.common.entity.UserTimeEntity;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author yifenrui
 * @since 2021-05-21
 */
@Data
@EqualsAndHashCode(callSuper = true)
@Accessors(chain = true)
public class MerchantExchangeGoodsPoints extends UserTimeEntity {

    private static final long serialVersionUID=1L;

    /**
     * 编码
     */
    private String code;

    /**
     * 代理商产品code
     */
    private String agentGoodsCode;

    /**
     * 积分商城产品名称
     */
    private String name;

    /**
     * 兑换积分
     */
    private BigDecimal exchangePoints;

    /**
     * 位置值
     */
    private Integer sort;

    /**
     * 备注
     */
    private String remark;

    /**
     * 状态 上架：UP_LIST，下架：DOWN_LIST
     */
    private String status;

    /**
     * 平台appid
     */
    private String miniAppid;

    /**
     * 平台名称-为了排序
     */
    private String miniAppidName;

    /**
     * 代理商产品-产品类型
     */
    @TableField(exist = false)
    private String agentProductName;

    /**
     * 代理商产品-产品面额/价值
     */
    @TableField(exist = false)
    private BigDecimal marketPrice;

    /**
     * 代理商产品-建议积分兑换值
     */
    @TableField(exist = false)
    private BigDecimal suggestExchangePointValue;

    /**
     * 代理商产品-代理商产品名称
     */
    @TableField(exist = false)
    private String agentGoodsName;

    /**
     * 代理商产品-代理商采购价
     */
    @TableField(exist = false)
    private BigDecimal purchasePrice;

    /**
     * 代理商产品-代理商产品状态
     */
    @TableField(exist = false)
    private String agentGoodsStatus;

    /**
     * 代理商产品-所属代理商
     */
    @TableField(exist = false)
    private String agentName;

    /**
     * 代理商编号
     */
    @TableField(exist = false)
    private String agentCode;

    @TableField(exist = false)
    private MerchantGoods MerchantGoods;

    /**
     * 分销仓库编号
     */
    private String whCode;

    /**
     * 分销仓库中库存的唯一标示号
     */
    private String stockSno;

    /**
     * 平台产品编号
     * 场景：1.在新增产品时如果平台产品启用了库存
     */
    @TableField(exist = false)
    private String platformGoodsCode;

}
